Documentation
¶
Overview ¶
Package examples provides usage examples for HR System Shared Libraries. This file demonstrates how to integrate the shared libraries into a microservice.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type ExampleService ¶
type ExampleService struct {
// contains filtered or unexported fields
}
ExampleService demonstrates how to structure a microservice using shared libraries.
func NewExampleService ¶
func NewExampleService() (*ExampleService, error)
NewExampleService creates a new example service instance.
Click to show internal directories.
Click to hide internal directories.